Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/nextcloud/richdocuments.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorJörn Friedrich Dreyer <jfd@butonic.de>2013-08-28 14:02:27 +0400
committerJörn Friedrich Dreyer <jfd@butonic.de>2013-08-28 14:02:27 +0400
commit7bc25ec0cea35427c06c0933a63549339dd30c20 (patch)
tree1eba718cdbc091270b085caf8f8b3350ba523c52 /appinfo/app.php
parent3e596044854831ee987e23dcc344794029c75033 (diff)
rename office -> documents
Diffstat (limited to 'appinfo/app.php')
-rwxr-xr-xappinfo/app.php24
1 files changed, 12 insertions, 12 deletions
diff --git a/appinfo/app.php b/appinfo/app.php
index cab0c474..7b521659 100755
--- a/appinfo/app.php
+++ b/appinfo/app.php
@@ -1,7 +1,7 @@
<?php
/**
* ownCloud - Office App
*
* @author Frank Karlitschek
* @copyright 2011 Frank Karlitschek karlitschek@kde.org
@@ -21,20 +21,20 @@
*
*/
-//OCP\Util::addStyle( 'office', 'style');
+//OCP\Util::addStyle( 'documents', 'style');
-OCP\App::register(array('order' => 70, 'id' => 'office', 'name' => 'Office'));
-OCP\App::registerAdmin('office', 'settings');
+OCP\App::register(array('order' => 70, 'id' => 'documents', 'name' => 'Documents'));
+OCP\App::registerAdmin('documents', 'settings');
OCP\App::addNavigationEntry(array(
- 'id' => 'office_index',
+ 'id' => 'documents_index',
'order' => 80,
- 'href' => OCP\Util::linkTo('office', 'index.php'),
- 'icon' => OCP\Util::imagePath('office', 'office.png'),
- 'name' => 'Office')
+ 'href' => OCP\Util::linkTo('documents', 'index.php'),
+ 'icon' => OCP\Util::imagePath('documents', 'documents.png'),
+ 'name' => 'Documents')
);
-OC::$CLASSPATH['OCA\Office\Controller'] = 'office/ajax/controller.php';
-OC::$CLASSPATH['OCA\Office\UserController'] = 'office/ajax/userController.php';
-OC::$CLASSPATH['OCA\Office\Download\Simple'] = 'office/lib/download/simple.php';
-OC::$CLASSPATH['OCA\Office\Download\Range'] = 'office/lib/download/range.php';
+OC::$CLASSPATH['OCA\Documents\Controller'] = 'documents/ajax/controller.php';
+OC::$CLASSPATH['OCA\Documents\UserController'] = 'documents/ajax/userController.php';
+OC::$CLASSPATH['OCA\Documents\Download\Simple'] = 'documents/lib/download/simple.php';
+OC::$CLASSPATH['OCA\Documents\Download\Range'] = 'documents/lib/download/range.php';
@@ -1,7 +1,7 @@
<?php
/**
- * ownCloud - Office App
+ * ownCloud - Documents App
*
* @author Frank Karlitschek